/*************************************************************************
 *
 *    Used with ICCARM and AARM.
 *
 *    (c) Copyright IAR Systems 2006
 *
 *    File name   : STR91x_Vic.h
 *    Description : Define API for VIC
 *
 *    History :
 *    1. Data        : February 10, 2006
 *       Author      : Stanimir Bonev
 *       Description : Create
 *
 *    $Revision: 1.0 $
 **************************************************************************/
#include <includes.h>

#ifndef __STR91x_VIC_H
#define __STR91x_VIC_H

#define IRQ_FLAG        0x80
#define FIQ_FLAG        0x40

// Interrupt protection type
typedef enum
{
  VIC_0 = 0, VIC_1
} VicController_t, *pVicController_t;

// Interrupt protection type
typedef enum
{
  UserandPrivilegedMode=0,
  PrivilegedMode
} Vic_ProtectionMode_t;

typedef enum
{
  VIC_Slot0 = 0,  // high priority
  VIC_Slot1,VIC_Slot2,VIC_Slot3,VIC_Slot4,VIC_Slot5,VIC_Slot6,VIC_Slot7,VIC_Slot8,
  VIC_Slot9,VIC_Slot10,VIC_Slot11,VIC_Slot12,VIC_Slot13,VIC_Slot14,VIC_Slot15
} VicIrqSlots_t;

/* Declare API functions */
/*************************************************************************
 * Function Name: VIC_SetProtectionMode
 * Parameters: VicController_t VicNumb,
 *             Vic_ProtectionMode_t ProtectionType
 * Return: None
 *
 * Description: According to the parameter - ProtectionType to decide the
 *              VIC access mode (previledged mode | user or previledged mode).
 *
 *************************************************************************/
void VIC_SetProtectionMode(VicController_t VicNumb,
                           Vic_ProtectionMode_t ProtectionType);

/*************************************************************************
 * Function Name: VIC_GetProtectionMode
 * Parameters: VicController_t VicNumb
 * Return: Vic_ProtectionMode_t
 *
 * Description: Get the VIC access mode (previledged mode |
 *              user or previledged mode).
 *
 *************************************************************************/
Vic_ProtectionMode_t VIC_GetProtectionMode(VicController_t VicNumb);

/*************************************************************************
 * Function Name: VIC_Init
 * Parameters: VicController_t VicNumb
 * Return: none
 *
 * Description: Initialize VIC
 *
 *************************************************************************/
void VIC_Init(VicController_t VicNumb);

/*************************************************************************
 * Function Name: VIC_GetIRQStatus
 * Parameters: VicController_t VicNumb
 * Return: Int32U
 *
 * Description: Get IRQ Status of VIC. Return register VICIRQSTATUS's value.
 *              If some IRQ interrupt request is enabled, then the
 *              corresponding bit of VICIRQSTATUS is set.
 *
 *************************************************************************/
//Int32U VIC_GetIRQStatus(VicController_t VicNumb);

/*************************************************************************
 * Function Name: VIC_GetFIQStatus
 * Parameters: VicController_t VicNumb
 * Return: Int32U
 *
 * Description: Get FIQ Status of VIC. Return register VICFIQSTATUS's value.
 *              If some FIQ interrupt request is enabled, then the corresponding
 *              bit of VICFIQSTATUS is set. If more that one interrupt request
 *              is assigned as FIQ, then invoking this function can decide which
 *              one or ones is/are the request source(s).
 *
 *************************************************************************/
//Int32U VIC_GetFIQStatus(VicController_t VicNumb);

/*************************************************************************
 * Function Name: VIC_EnableInt
 * Parameters: VicController_t VicNumb, Int32U IntType
 * Return: none
 *
 * Description: Enable specific interrupt
 *
 *************************************************************************/
void VIC_EnableInt(VicController_t VicNumb, Int32U IntType);

/*************************************************************************
 * Function Name: VIC_DisableInt
 * Parameters: VicController_t VicNumb, Int32U IntType
 * Return: none
 *
 * Description: Disable specific interrupt
 *
 *************************************************************************/
void VIC_DisableInt(VicController_t VicNumb, Int32U IntType);

/*************************************************************************
 * Function Name: VIC_EnableNonVectoredIRQ
 * Parameters: VicController_t VicNumb,
 *             pIRQSub - Non Vectored IRQ Sub address
 * Return: none
 *
 * Description: Set VICDefVectAddr to be the IRQ Sub address.
 *
 *************************************************************************/
void VIC_EnableNonVectoredIRQ(VicController_t VicNumb,void(*pIRQSub)());

/*************************************************************************
 * Function Name: VIC_DisableNonVectoredIRQ
 * Parameters: VicController_t VicNumb
 * Return: none
 *
 * Description: set VICDefVectAddr to be reset value (NULL).
 *
 *************************************************************************/
void VIC_DisableNonVectoredIRQ(VicController_t VicNumb);

/*************************************************************************
 * Function Name: VIC_SetVectoredIRQ
 * Parameters:  VicController_t VicNumb,void(*pIRQSub)(),
 *              VicIrqSlots_t VicIrqSlot, Int32U VicIntSource
 *
 *
 * Return: none
 *
 * Description:  Init vectored inerrutps
 *
 *************************************************************************/
void VIC_SetVectoredIRQ(VicController_t VicNumb,void(*pIRQSub)(),
                    VicIrqSlots_t VicIrqSlot, Int32U VicIntSource);

/*************************************************************************
 * Function Name: VIC_SetFastInt
 * Parameters: VicController_t VicNumb, Int32U FastIntMask
 * Return: None
 *
 * Description: Enable FIQ interrupt
 *
 *************************************************************************/
void VIC_EnaFastInt(VicController_t VicNumb, Int32U FastIntMask);

/*************************************************************************
 * Function Name: VIC_DisFastInt
 * Parameters: VicController_t VicNumb, Int32U FastIntMask
 * Return: none
 *
 * Description: Disable FIQ interrupt
 *
 *************************************************************************/
void VIC_DisFastInt(VicController_t VicNumb, Int32U FastIntMask);

/*************************************************************************
 * Function Name: restore_IRQ
 * Parameters: unsigned long IFlag
 * Return: void
 * Description: Restore I flag state
 *
 *************************************************************************/
inline
__arm void restore_IRQ(unsigned long IFlag)
{
unsigned long tmp;
  tmp=__get_CPSR();
  __set_CPSR(tmp & (IFlag | ~IRQ_FLAG));
}

 /*************************************************************************
 * Function Name: disable_IRQ
 * Parameters:
 * Return: unsigned long
 * Description: Disable IRQ and return previous state state of flgas I
 *
 *************************************************************************/
inline
__arm unsigned long disable_IRQ(void)
{
unsigned long tmp;
  tmp=__get_CPSR();
  __set_CPSR(tmp | IRQ_FLAG);
  return tmp & IRQ_FLAG;
}

 /*************************************************************************
 * Function Name: restore_interrupts
 * Parameters: unsigned long IFlag
 * Return: void
 * Description: Restore F,I flag state
 *
 *************************************************************************/
inline
__arm void restore_interrupts(unsigned long IFlag)
{
unsigned long tmp;
  tmp=__get_CPSR();
  __set_CPSR(tmp & (IFlag | ~(IRQ_FLAG | FIQ_FLAG)));
}

 /*************************************************************************
 * Function Name: disable_interrupts
 * Parameters:
 * Return: unsigned long
 * Description: Disable interrupts and return previous state state of flgas I
 *
 *************************************************************************/
inline
__arm unsigned long disable_interrupts(void)
{
unsigned long tmp;
  tmp=__get_CPSR();
  __set_CPSR(tmp | IRQ_FLAG | FIQ_FLAG);
  return tmp;
}

#endif // __STR91x_VIC_H

